arrow-csv 56.2.1

Support for parsing CSV format to and from the Arrow format
docs.rs failed to build arrow-csv-56.2.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: arrow-csv-58.3.0

Transfer data between the Arrow memory format and CSV (comma-separated values).