RecordDecoder

Struct RecordDecoder 

pub struct RecordDecoder {
    delimiter: Reader,
    num_columns: usize,
    line_number: usize,
    offsets: Vec<usize>,
    offsets_len: usize,
    current_field: usize,
    num_rows: usize,
    data: Vec<u8>,
    data_len: usize,
    truncated_rows: bool,
    truncated_row_count: usize,
}
RecordDecoder provides a push-based interface to decoder StringRecords

Fields

delimiter: Readernum_columns: usize

The expected number of fields per row

line_number: usize

The current line number

offsets: Vec<usize>

Offsets delimiting field start positions

offsets_len: usize

The current offset into self.offsets

We track this independently of Vec to avoid re-zeroing memory

current_field: usize

The number of fields read for the current record

num_rows: usize

The number of rows buffered

data: Vec<u8>

Decoded field data

data_len: usize

Offsets into data

We track this independently of Vec to avoid re-zeroing memory

truncated_rows: bool

Whether rows with less than expected columns are considered valid

Default value is false When enabled fills in missing columns with null

truncated_row_count: usize

The number of rows padded because they had fewer fields than expected

Only incremented when truncated_rows is enabled. Cumulative over the lifetime of this decoder, i.e. not reset by Self::flush, but reset by Self::clear along with the buffered rows it counted

Implementations

Source

impl RecordDecoder

pub fn new(delimiter: Reader, num_columns: usize, truncated_rows: bool) -> Self

pub fn decode( &mut self, input: &[u8], to_read: usize, ) -> Result<(usize, usize), ArrowError>

Decodes records from input returning the number of records and bytes read

Note: this expects to be called with an empty input to signal EOF

pub fn len(&self) -> usize

Returns the current number of buffered records

pub fn is_empty(&self) -> bool

Returns true if the decoder is empty

pub fn truncated_row_count(&self) -> usize

Returns the number of rows padded because they had fewer fields than expected

Cumulative across Self::flush calls, reset by Self::clear

pub fn clear(&mut self)

Clears the current contents of the decoder

pub fn flush(&mut self) -> Result<StringRecords<'_>, ArrowError>

Flushes the current contents of the reader